@@ -5,8 +5,17 @@
 # ---------------------------------------------------------------------------------------
 # version | date     | author   | changes
 # ---------------------------------------------------------------------------------------
+# 0.16    |< 02.03.02| JSTENZEL | added DIRCTIVE_DSTREAM_ENTRYPOINT constant;
+#         |02.03.2002| JSTENZEL | added DSTREAM_... constants;
+#         |29.09.2001| JSTENZEL | added STREAM_DOCSTREAMS;
+# 0.15    |10.08.2001| JSTENZEL | added STREAM_... constants;
+#         |          | JSTENZEL | reorganized POD slightly;
+#         |14.08.2001| JSTENZEL | added missed doc of TAG_... constants;
+#         |29.09.2001| JSTENZEL | removed STREAM_CONTROL;
+#         |13.11.2001| JSTENZEL | added PARSING_IGNORE and PARSING_ERASE;
+#         |14.11.2001| JSTENZEL | added STREAM_DIR_ index constants;
 # 0.14    |28.05.2001| JSTENZEL | added DIRECTIVE_VARRESET;
-#         |12.06.2001| JSTENZEL | added PARSER_... constants;
+#         |12.06.2001| JSTENZEL | added PARSING_... constants;
 # 0.13    |18.03.2001| JSTENZEL | added tag constants;
 # 0.12    |14.03.2001| JSTENZEL | added mailing list hint to POD;
 # 0.11    |20.01.2001| JSTENZEL | added new constant DIRECTIVE_VARSET;
@@ -33,11 +42,11 @@
 
 =head1 NAME
 
-B<PerlPoint::Constants> - public PerlPoint::... module constants
+B<PerlPoint::Constants> - public PerlPoint module constants
 
 =head1 VERSION
 
-This manual describes version B<0.14>.
+This manual describes version B<0.16>.
 
 =head1 DESCRIPTION
 
@@ -57,7 +66,7 @@ of the using modules B<PerlPoint::Parser> and B<PerlPoint::Backend>.
 package PerlPoint::Constants;
 
 # declare version
-$VERSION=$VERSION=0.14;
+$VERSION=$VERSION=0.16;
 
 # startup actions
 BEGIN
@@ -111,6 +120,10 @@ flags a "definition point" paragraph;
 
 flags a "definition point" item (the stuff to be defined);
 
+=item DIRECTIVE_DSTREAM_ENTRYPOINT
+
+flags the switch into another document stream;
+
 =item DIRECTIVE_HEADLINE
 
 flags a headline;
@@ -177,51 +190,33 @@ flags a verbatim block paragraph;
 
   # directive constants
   startupGenerateConstants(
-                           'DIRECTIVE_START',        # entity start;
-                           'DIRECTIVE_COMPLETE',     # entity complete;
+                           'DIRECTIVE_START',                  # entity start;
+                           'DIRECTIVE_COMPLETE',               # entity complete;
 
-                           'DIRECTIVE_BLOCK',        # block;
-                           'DIRECTIVE_COMMENT',      # comment;
-                           'DIRECTIVE_DLIST',        # definition list;
-                           'DIRECTIVE_DOCUMENT',     # document;
-                           'DIRECTIVE_DPOINT',       # definition list point;
-                           'DIRECTIVE_DPOINT_ITEM',  # definition list point;
-                           'DIRECTIVE_HEADLINE',     # headline;
-                           'DIRECTIVE_LIST_LSHIFT',  # shift list left;
-                           'DIRECTIVE_LIST_RSHIFT',  # shift list right;
-                           'DIRECTIVE_NEW_LINE',     # backend line hint;
-                           'DIRECTIVE_OLIST',        # ordered list;
-                           'DIRECTIVE_OPOINT',       # ordered list point;
-                           'DIRECTIVE_TAG',          # tag;
-                           'DIRECTIVE_TEXT',         # text;
-                           'DIRECTIVE_ULIST',        # unordered list;
-                           'DIRECTIVE_UPOINT',       # unordered list point;
-                           'DIRECTIVE_VARSET',       # backend hint: variable setting;
-                           'DIRECTIVE_VARRESET',     # backend hint: reset *all* variables;
-                           'DIRECTIVE_VERBATIM',     # verbatim;
+                           'DIRECTIVE_BLOCK',                  # block;
+                           'DIRECTIVE_COMMENT',                # comment;
+                           'DIRECTIVE_DLIST',                  # definition list;
+                           'DIRECTIVE_DOCUMENT',               # document;
+                           'DIRECTIVE_DPOINT',                 # definition list point;
+                           'DIRECTIVE_DPOINT_ITEM',            # definition list point;
+                           'DIRECTIVE_HEADLINE',               # headline;
+                           'DIRECTIVE_LIST_LSHIFT',            # shift list left;
+                           'DIRECTIVE_LIST_RSHIFT',            # shift list right;
+                           'DIRECTIVE_NEW_LINE',               # backend line hint;
+                           'DIRECTIVE_OLIST',                  # ordered list;
+                           'DIRECTIVE_OPOINT',                 # ordered list point;
+                           'DIRECTIVE_TAG',                    # tag;
+                           'DIRECTIVE_TEXT',                   # text;
+                           'DIRECTIVE_ULIST',                  # unordered list;
+                           'DIRECTIVE_UPOINT',                 # unordered list point;
+                           'DIRECTIVE_VARSET',                 # backend hint: variable setting;
+                           'DIRECTIVE_VARRESET',               # backend hint: reset *all* variables;
+                           'DIRECTIVE_VERBATIM',               # verbatim;
+                           'DIRECTIVE_DSTREAM_ENTRYPOINT',     # document stream entry point;
 
-                           'DIRECTIVE_SIMPLE',       # a pseudo directive (never used directly - MUST be the last here!);
+                           'DIRECTIVE_SIMPLE',                 # a pseudo directive (never used directly - MUST be the last here!);
                           );
 
-  # parser constants
-  startupGenerateConstants(
-                           'PARSING_OK',             # all right, proceed;
-                           'PARSING_COMPLETED',      # we know without further parsing that the input was perfect;
-                           'PARSING_ERROR',          # a semantic error occured;
-                           'PARSING_FAILED',         # a syntactical error occured;
-                          );
-
-  # tag constants
-  startupGenerateConstants(
-                           'TAGS_OPTIONAL',          # something is optional;
-                           'TAGS_MANDATORY',         # something is mandatory;
-                           'TAGS_DISABLED',          # something is disabled (not necessary);
-                          );
-
-  # release memory
-  undef &startupGenerateConstants;
-
-
 =pod
 
 =head2 Parser constants
@@ -234,20 +229,196 @@ control how the parser continues processing, usually used by tag hooks.
 
 We read all we need. Stop parsing successfully.
 
+=item PARSING_ERASE
+
+Ignore the tag I<and all its contents> (which means its body).
+
 =item PARSING_ERROR
 
-A semantic error occurred. Parsing will usually be continued to possibly detect even more errors.
+A semantic error occurred. Parsing will usually be continued
+to possibly detect even more errors.
 
 =item PARSING_FAILED
 
 A syntactic error occured. Parsing will be stopped immediately.
 
+=item PARSING_IGNORE
+
+Ignore the tag as if it was not written.
+
 =item PARSING_OK
 
 Input ok, parsing can be continued.
 
 =back
 
+=cut
+
+  # parser constants
+  startupGenerateConstants(
+                           'PARSING_OK',             # all right, proceed;
+                           'PARSING_COMPLETED',      # we know without further parsing that the input was perfect;
+                           'PARSING_ERROR',          # a semantic error occured;
+                           'PARSING_FAILED',         # a syntactical error occured;
+                           'PARSING_IGNORE',         # ignore the tag;
+                           'PARSING_ERASE',          # ignore the tag *and all its content*;
+                          );
+
+
+=pod
+
+=head2 Tag definition constants
+
+flagging mode of tag components.
+
+=over 4
+
+=item TAGS_OPTIONAL
+
+the item can be used but is not required.
+
+=item TAGS_MANDATORY
+
+the item is an essential tag part.
+
+=item TAGS_DISABLED
+
+the item must not be used.
+
+=back
+
+=cut
+
+
+  # tag constants
+  startupGenerateConstants(
+                           'TAGS_OPTIONAL',          # something is optional;
+                           'TAGS_MANDATORY',         # something is mandatory;
+                           'TAGS_DISABLED',          # something is disabled (not necessary);
+                          );
+
+
+
+=pod
+
+=head2 Stream data structure part constants
+
+index constants to access parts of the intermediate data structure produced
+by the parser and processed by backends. Intended to be used by C<PerlPoint::Parser>
+and C<PerlPoint::Backend>.
+
+=over 4
+
+=item STREAM_IDENT
+
+stream data identifier - a string identifying the data structure as a PerlPoint stream.
+
+=item STREAM_DOCSTREAMS
+
+a list of all detected document stream identifiers.
+
+=item STREAM_TOKENS
+
+token stream.
+
+=item STREAM_HEADLINES
+
+headline stream.
+
+=back
+
+=cut
+
+
+  # stream data structure part constants
+  startupGenerateConstants(
+                           'STREAM_IDENT',           # stream data identifier;
+                           'STREAM_DOCSTREAMS',      # list of document streams (hash);
+                           'STREAM_TOKENS',          # token stream;
+                           'STREAM_HEADLINES',       # headline stream;
+                          );
+
+
+=pod
+
+=head2 Stream directive data structure index constants
+
+index constants to access parts of a stream directive.
+
+=over 4
+
+=item STREAM_DIR_HINTS
+
+a hash filled by the parser to control backend behaviour.
+
+=item STREAM_DIR_TYPE
+
+directive type constant (C<DIRECTIVE_HEADLINE>, C<DIRECTIVE_TAG> etc.)
+
+=item STREAM_DIR_STATE
+
+start/completion flag (C<DIRECTIVE_START>, C<DIRECTIVE_COMPLETE>).
+
+=item STREAM_DIR_DATA
+
+beginning of the data part, depends on directive type.
+
+
+=back
+
+=cut
+
+
+  # stream directive data structure index constants
+  startupGenerateConstants(
+                           'STREAM_DIR_HINTS',       # backend hints stored by the parser;
+                           'STREAM_DIR_TYPE',        # directive type;
+                           'STREAM_DIR_STATE',       # directive state (starting, complete);
+                           'STREAM_DIR_DATA',        # data part (index of first element);
+                          );
+
+
+=pod
+
+=head2 Document stream handling constants
+
+declare how document streams should be handled by the parser.
+
+=over 4
+
+=item DSTREAM_DEFAULT
+
+Document stream entry points are streamed directly - so the backend
+can handle them.
+
+=item DSTREAM_IGNORE
+
+Document streams (except of the main stream) are completely ignored.
+
+=item DSTREAM_HEADLINES
+
+Document stream entry points are streamed as headlines.
+
+=back
+
+=cut
+
+  # declare display constants
+  startupGenerateConstants(
+                           'DSTREAM_DEFAULT',        # just stream them;
+                           'DSTREAM_IGNORE',         # ignore all streams except of "main";
+                           'DSTREAM_HEADLINES',      # stream entry points as headlines;
+                          );
+ }
+
+
+
+
+  # release memory
+  undef &startupGenerateConstants;
+
+
+=pod
 
 =head2 Trace constants
 
@@ -329,6 +500,7 @@ suppresses warnings;
   use constant 'DISPLAY_NOINFO'   => 1;            # suppress informations;
   use constant 'DISPLAY_NOWARN'   => 2;            # suppress warnings;
 
+
 =pod
 
 =head2 Cache constants
@@ -364,7 +536,8 @@ Cleans up an existing cache before the parser starts (and possibly rebuilds it).
   use constant 'CACHE_OFF'        => 0;            # MUST be 0! Deactivates the cache.
   use constant 'CACHE_ON'         => 1;            # activates the cache;
   use constant 'CACHE_CLEANUP'    => 2;            # cache cleanup;
- }
+
+
 
 # modules
 use Exporter;
@@ -381,6 +554,7 @@ use Exporter;
            DIRECTIVE_DOCUMENT
            DIRECTIVE_DPOINT
            DIRECTIVE_DPOINT_ITEM
+           DIRECTIVE_DSTREAM_ENTRYPOINT
            DIRECTIVE_HEADLINE
            DIRECTIVE_LIST_LSHIFT
            DIRECTIVE_LIST_RSHIFT
@@ -412,16 +586,25 @@ use Exporter;
 	   CACHE_OFF
 	   CACHE_ON
 	   CACHE_CLEANUP
+
+	   DSTREAM_DEFAULT
+	   DSTREAM_IGNORE
+           DSTREAM_HEADLINES
           );
 
 %EXPORT_TAGS=(
-              parsing => [qw(PARSING_OK PARSING_COMPLETED PARSING_ERROR PARSING_FAILED)],
+              parsing => [qw(PARSING_OK PARSING_COMPLETED PARSING_ERROR PARSING_FAILED PARSING_IGNORE PARSING_ERASE)],
+              stream  => [qw(
+                             STREAM_IDENT STREAM_DOCSTREAMS STREAM_TOKENS STREAM_HEADLINES
+                             STREAM_DIR_HINTS STREAM_DIR_TYPE STREAM_DIR_STATE STREAM_DIR_DATA
+                            )],
               tags    => [qw(TAGS_OPTIONAL TAGS_MANDATORY TAGS_DISABLED)],
              );
 
 Exporter::export_ok_tags(
                          qw(
                             parsing
+                            stream
                             tags
                            )
                         );
